package fr.inria.phoenix.diasuite.framework.context.alert;

import java.io.Serializable;

/**
 * An object to store a value published by the context <code>Alert</code>.
 * <p>
 * Detect urgent events such as a forced door, a stuck door, or a blackout
 *
 * <pre>
 * context Alert as String {
 * 	when provided state from DoorLocker maybe publish;
 * }
 * </pre>
 */
public final class AlertValue implements Serializable {
    private static final long serialVersionUID = 0;
    
    private java.lang.String value;
    
    /**
     * Get the value of the context <code>Alert</code>
     * 
     * <p>
     * Detect urgent events such as a forced door, a stuck door, or a blackout
     * 
     * @return the value of the context <code>Alert</code>
     */
    public java.lang.String value() {
        return value;
    }
    
    public AlertValue(java.lang.String value) {
        this.value = value;
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((value == null) ? 0 : value.hashCode());
        return result;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        AlertValue other = (AlertValue) obj;
        if (value == null) {
            if (other.value != null)
                return false;
        } else if (!value.equals(other.value))
            return false;
        return true;
    }
}
