package fr.inria.phoenix.scenario.doorlocks.impl.context;

import fr.inria.diagen.core.ServiceConfiguration;
import fr.inria.phoenix.diasuite.framework.context.alert.AbstractAlert;
import fr.inria.phoenix.diasuite.framework.device.doorlocker.StateFromDoorLocker;

/* Detect urgent events such as a forced door, a stuck door, or a blackout.
 * The implementation of the Alert context
 * @see fr.inria.phoenix.diasuite.framework.context.alert.AbstractAlert
 */
public class Alert extends AbstractAlert {
    
    public Alert(ServiceConfiguration serviceConfiguration) {
        super(serviceConfiguration);
    }
    
    /* (non-Javadoc)
     * @see fr.inria.phoenix.diasuite.framework.context.alert.AbstractAlert#onStateFromDoorLocker(StateFromDoorLocker)
     */
    @Override
    protected AlertValuePublishable onStateFromDoorLocker(StateFromDoorLocker stateFromDoorLocker) {
    	String state = stateFromDoorLocker.value().getState();
    	String user = stateFromDoorLocker.sender().user();
    	String location = stateFromDoorLocker.sender().location();
    	// Don't send any message for battery-only reports
    	if(!state.matches(".*(forced|stuck|blackout).*"))
    		return new AlertValuePublishable(null, false);
    	
    	// At this point, something critical happened.
    	StringBuffer message = new StringBuffer("Critical event(s) happened on door " +
    			"@" + user + "/" + location + ":\n");
    	if(state.matches(".*forced.*")) {
    		message.append("- The door has been forced!!\n");
    	}
    	if(state.matches(".*stuck.*")) {
    		message.append("- The door is stuck!\n");
    	}
    	if(state.matches(".*blackout.*")) {
    		message.append("- A blackout has been detected.\n");
    	}
    	return new AlertValuePublishable(message.toString(), true);
    }
}
