package fr.inria.phoenix.scenario.doorlocks.impl.context;

import fr.inria.diagen.core.ServiceConfiguration;
import fr.inria.phoenix.diasuite.framework.context.format.AbstractFormat;
import fr.inria.phoenix.diasuite.framework.datatype.event.Event;
import fr.inria.phoenix.diasuite.framework.datatype.state.State;
import fr.inria.phoenix.diasuite.framework.device.doorlocker.BatstateFromDoorLocker;
import fr.inria.phoenix.diasuite.framework.device.doorlocker.LockedFromDoorLocker;
import fr.inria.phoenix.diasuite.framework.device.doorlocker.StateFromDoorLocker;

/* Format various events for logging purpose.
 * The implementation of the Format context
 * @see fr.inria.phoenix.diasuite.framework.context.format.AbstractFormat
 */
public class Format extends AbstractFormat {
    
    public Format(ServiceConfiguration serviceConfiguration) {
        super(serviceConfiguration);
    }
    
    static private String formatEvent(String event, String user, String location) {
    	return event + "@" + user + "/" + location;
    }
    
    /* (non-Javadoc)
     * @see fr.inria.phoenix.diasuite.framework.context.format.AbstractFormat#onLockedFromDoorLocker(LockedFromDoorLocker)
     */
    @Override
    protected Event onLockedFromDoorLocker(LockedFromDoorLocker lockedFromDoorLocker) {
    	final Boolean debug = true;
    	String user = lockedFromDoorLocker.sender().user();
    	String location = lockedFromDoorLocker.sender().location();
    	Boolean locked = lockedFromDoorLocker.value();
       	String content = formatEvent((locked? "locked": "unlocked"), user, location);
    	return new Event(content, 
    			debug? "20150101235959000": new java.util.Date().toString()); 
    }
    
    /* (non-Javadoc)
     * @see fr.inria.phoenix.diasuite.framework.context.format.AbstractFormat#onStateFromDoorLocker(StateFromDoorLocker)
     */
    @Override
    protected Event onBatstateFromDoorLocker(BatstateFromDoorLocker batstateFromDoorLocker) {
    	String user = batstateFromDoorLocker.sender().user();
    	String location = batstateFromDoorLocker.sender().location();
    	State state = batstateFromDoorLocker.value();
    	String content = formatEvent(state.getState(), user, location);
    	return new Event(content, state.getTimestamp());
    }

	@Override
	protected Event onStateFromDoorLocker(
			StateFromDoorLocker stateFromDoorLocker) {
    	String user = stateFromDoorLocker.sender().user();
    	String location = stateFromDoorLocker.sender().location();
    	State state = stateFromDoorLocker.value();
    	String content = formatEvent(state.getState(), user, location);
    	return new Event(content, state.getTimestamp());
	}
}
